# frozen_string_literal: true

require 'jekyll/page'
require_relative 'helper'

module Jekyll
  module ActivityPub
    # Represents a removed activity
    class Tombstone < Jekyll::Page
      include Helper

      # @param :object_id [String]
      attr_reader :object_id

      # Initialize with default data
      #
      # @param :site [Jekyll::Site]
      # @param :object_id [String]
      def initialize(site, object_id, )
        @context = StubContext.new(registers: { site: site })
        @object_id = object_id

        dest = Pathname.new(object.destination(site.dest)).relative_path_from(site.dest)
        name = 'tombstone.jsonld'
        dir = File.join(
          File.dirname(dest),
          File.basename(dest, '.jsonld')
        )

        super(site, '', dir, name)

        trigger_hooks :post_init
      end

      def read_yaml(*)
        @data = {
          '@context' => 'https://www.w3.org/ns/activitystreams',
          'type' => 'Tomsbtone',
          'id' => absolute_url(object_id),
          'published' => object.data[DATE_ATTRIBUTE],
          'to' => object.data['to'],
          'cc' => object.data['cc'],
          'object' => object.data,
          'inReplyTo' => object.data['in_reply_to']
        }
      end

      # @return [Time]
      def date
        @date ||= Time.parse(object.data[DATE_ATTRIBUTE])
      end

      private

      def type
        @type ||= self.class.name.split('::').last
      end
    end
  end
end

